/**
 * JORM: an implementation of a generic mapping system for persistent Java
 *       objects. Two mappings are supported: to RDBMS and to binary files.
 * Copyright (C) 2001-2004 France Telecom R&D - INRIA
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: jorm-team@objectweb.org
 *
 */
package jorm.rdb;

// Import clauses required by jorm
import org.objectweb.jorm.api.Debug;
import org.objectweb.jorm.api.PAccessor;
import org.objectweb.jorm.api.PAccessorGen;
import org.objectweb.jorm.api.PClassMapping;
import org.objectweb.jorm.api.PBinding;
import org.objectweb.jorm.api.PBindingCtrl;
import org.objectweb.jorm.api.PException;
import org.objectweb.jorm.api.PExceptionProtocol;
import org.objectweb.jorm.api.PExceptionIO;
import org.objectweb.jorm.api.PExceptionNoDSI;
import org.objectweb.jorm.api.PStateGraph;
import org.objectweb.jorm.naming.api.PName;
import org.objectweb.jorm.naming.api.PNameGetter;
import org.objectweb.jorm.naming.api.PNameCoder;
import org.objectweb.jorm.naming.api.PExceptionNaming;
import org.objectweb.jorm.type.api.PExceptionTyping;
import org.objectweb.jorm.type.api.PType;
import org.objectweb.jorm.type.api.PTypeSpace;
import org.objectweb.util.monolog.api.BasicLevel;
import org.objectweb.medor.api.MedorException;
import org.objectweb.medor.eval.prefetch.api.PrefetchCache;
import org.objectweb.medor.tuple.api.Tuple;

import java.math.BigDecimal;
import java.math.BigInteger;
import java.util.Date;
// Import clauses required by the object Olstore_order
import jorm.Olstore_orderAccessor;
// Imports needed by the rdb mapper
import java.sql.Connection;
import java.sql.ResultSet;
import java.sql.PreparedStatement;
import java.sql.SQLException;
import java.sql.Types;
import java.io.IOException;
import org.objectweb.jorm.naming.api.PNameCoder;
import org.objectweb.jorm.mapper.rdb.lib.PMapperRdb;
import org.objectweb.jorm.mapper.rdb.adapter.api.RdbAdapter;
import org.objectweb.jorm.mapper.rdb.adapter.api.RdbAdapterException;
import org.objectweb.jorm.mapper.rdb.lib.RdbConnectionWrapper;

public class Olstore_orderBinding
	extends org.objectweb.jonas_ejb.container.JEntitySwitchCS
	implements PBindingCtrl
      {
	/**
	 * The current state of this PBinding object.
	 */
	transient protected byte status;
	/**
	 * The PClassMapping linked to this PBinding object.
	 */
	transient public Olstore_orderMapping pClassMapping;
	/**
	 * The PName of this PBinding object.
	 */
	transient protected PName pname;
	transient RdbAdapter adapter;

	public Olstore_orderBinding() {
// nothing
	}

	public Olstore_orderBinding(PClassMapping pcm) {
		pClassMapping = (Olstore_orderMapping) pcm;
// nothing
	}


	// IMPLEMENTATION OF METHODS FROM THE PBinding INTERFACE

	public void init(PClassMapping pcm) throws PException {
		pClassMapping = (Olstore_orderMapping) pcm;
		status = PBinding.LIFECYCLE_NOTBOUND;
	    pname = null;
		if (pcm != null) {
			PMapperRdb mapper = (PMapperRdb) pcm.getPMapper();
			if (mapper != null) {
				adapter = mapper.getRdbAdapter();
			}
		}
		if (adapter == null) {
			throw new PException("No mapper found throught the PClassMapping: " + pcm);
		}
	}

	public void write(Object conn, PAccessor pa)
		throws PException {
		Olstore_orderAccessor paccessor = null;
		PAccessorGen paccessorGen = null;
		if (pa == null)
			throw new PExceptionProtocol("Accessor must not be null");
		else if (pa instanceof Olstore_orderAccessor)
			paccessor = (Olstore_orderAccessor) pa;
		else if (pa instanceof PAccessorGen)
			paccessorGen = (PAccessorGen) pa;
		else
			throw new PExceptionProtocol("Wrong type of accessor: " + pa);
		byte nextState =
			PStateGraph.nextStatePBinding(status, PBinding.ACTION_WRITE);
		if (nextState == PBinding.LIFECYCLE_ERROR)
			throw new PExceptionProtocol("Unauthorized WRITE operation, status=" + status);
		Connection connection = RdbConnectionWrapper.narrow2SQL(conn);
		try {
			String sqlquery;
		    if (status == PBinding.LIFECYCLE_DELTOWRITE) {
			if (Debug.ON && pClassMapping!=null && pClassMapping.logger.isLoggable(BasicLevel.DEBUG)) pClassMapping.logger.log(BasicLevel.DEBUG, "Remove");
//Table olstore_order : readOnly=false mustGenerateUpdate=true colocatedTable=false joins=$tab.joins
                sqlquery = deleteolstore_orderTable(connection, conn, paccessorGen, paccessor);
                if (sqlquery != null) {
                    throw new PExceptionIO("Risk to loose modifications to class [Olstore_order]: problematic SQL query -> {" + sqlquery + "}");
                }
            } else if (status==PBinding.LIFECYCLE_NEWTOWRITE) {
			if (Debug.ON && pClassMapping!=null && pClassMapping.logger.isLoggable(BasicLevel.DEBUG)) pClassMapping.logger.log(BasicLevel.DEBUG, "Insert");
                sqlquery = insertolstore_orderTable(connection, conn, paccessorGen, paccessor);
                if (sqlquery != null) {
                    throw new PExceptionIO("Risk to loose modifications to class [Olstore_order]: problematic SQL query -> {" + sqlquery + "}");
                }
		    } else if (status==PBinding.LIFECYCLE_ACTIVEFORIO) {
			if (Debug.ON && pClassMapping!=null && pClassMapping.logger.isLoggable(BasicLevel.DEBUG)) pClassMapping.logger.log(BasicLevel.DEBUG, "Update");
                sqlquery = updateolstore_orderTable(connection, conn, paccessorGen, paccessor);
                if (sqlquery != null) {
                    throw new PExceptionIO("Risk to loose modifications to class [Olstore_order]: problematic SQL query -> {" + sqlquery + "}");
                }
		    }
		} catch (java.sql.SQLException se) {
			throw new PExceptionIO(se, "SQL problem while writing the DSI.");
		} catch (java.io.IOException ioe) {
			throw new PExceptionIO(ioe, "Stream IO problem while writing the DSI.");
		} catch (RdbAdapterException rae) {
			throw new PExceptionIO(rae, "SQL problem while writing the DSI.");
		}
		// Changing the current state
		status = nextState;
	}

	public void read(Object conn, PAccessor pa) throws PException {
		if (Debug.ON && pClassMapping!=null && pClassMapping.logger.isLoggable(BasicLevel.DEBUG)) pClassMapping.logger.log(BasicLevel.DEBUG, "Read");
		Olstore_orderAccessor paccessor = null;
		PAccessorGen paccessorGen = null;
		if (pa == null)
			throw new PExceptionProtocol("Accessor must not be null");
		else if (pa instanceof Olstore_orderAccessor)
			paccessor = (Olstore_orderAccessor) pa;
		else if (pa instanceof PAccessorGen)
			paccessorGen = (PAccessorGen) pa;
		else
			throw new PExceptionProtocol("Wrong type of accessor: " + pa);
		byte nextState =
			PStateGraph.nextStatePBinding(status, PBinding.ACTION_READ);
		if (nextState==PBinding.LIFECYCLE_ERROR)
			throw new PExceptionProtocol("Unauthorized READ operation, status=" + status);
		Connection connection = RdbConnectionWrapper.narrow2SQL(conn);
        PreparedStatement pstmt = null;
        ResultSet resultSet = null;
        PException resex = null;
		try {
            pstmt = connection.prepareStatement(pClassMapping.readQuery);
            adapter.setOint(pstmt, 1, pname.encodeOint());
            resultSet = pstmt.executeQuery();
            if(resultSet.next() == false)
                throw new PExceptionNoDSI(
                    "No entry matching with the following identifier: " + pname);
            PName refname;
            Object fieldval;
            long notnullval;
			if (paccessor != null) {
				//read public primitive fields
                paccessor.paSetDateReceived(adapter.getString(resultSet, 1, null));
                paccessor.paSetOrderId(adapter.getOint(resultSet, 4, null));
                paccessor.paSetPricePaid(adapter.getBigDecimal(resultSet, 5, null));
                paccessor.paSetQuantity(adapter.getOint(resultSet, 6, null));
                paccessor.paSetStatus(adapter.getString(resultSet, 7, null));
				//decode PName for references
				//writeReadRef  isSpecific=true gen_ref=org.objectweb.jorm.mapper.rdb.generator.RdbGenRef@d8e902
				//fieldName=item_itemId
                fieldval = adapter.getOint(resultSet, 2, null);
                if (resultSet.wasNull()) {
                    refname = pClassMapping.itemPnc.decodeOint(null);
                } else {
                    refname = pClassMapping.itemPnc.decodeOint((java.lang.Integer) fieldval);
                }
                paccessor.paSetItem(refname, conn);
				//writeReadRef  isSpecific=true gen_ref=org.objectweb.jorm.mapper.rdb.generator.RdbGenRef@1bde3d2
				//fieldName=user_username
                fieldval = adapter.getString(resultSet, 3, null);
                if (resultSet.wasNull()) {
                    refname = pClassMapping.userPnc.decodeString(null);
                } else {
                    refname = pClassMapping.userPnc.decodeString((java.lang.String) fieldval);
                }
                paccessor.paSetUser(refname, conn);
			} else if (paccessorGen != null) {
				//read public primitive fields
                paccessorGen.paSetStringField(pClassMapping.dateReceived_NAME, adapter.getString(resultSet, 1, null));
                paccessorGen.paSetOintField(pClassMapping.orderId_NAME, adapter.getOint(resultSet, 4, null));
                paccessorGen.paSetBigDecimalField(pClassMapping.pricePaid_NAME, adapter.getBigDecimal(resultSet, 5, null));
                paccessorGen.paSetOintField(pClassMapping.quantity_NAME, adapter.getOint(resultSet, 6, null));
                paccessorGen.paSetStringField(pClassMapping.status_NAME, adapter.getString(resultSet, 7, null));
				//decode PName for references
				//writeReadRef  isSpecific=false gen_ref=org.objectweb.jorm.mapper.rdb.generator.RdbGenRef@1bde3d2
				//fieldName=user_username
                fieldval = adapter.getString(resultSet, 3, null);
                if (resultSet.wasNull()) {
                    refname = pClassMapping.userPnc.decodeString(null);
                } else {
                    refname = pClassMapping.userPnc.decodeString((java.lang.String) fieldval);
                }
                paccessorGen.paSetRefField(pClassMapping.user_NAME, refname, conn);
				//writeReadRef  isSpecific=false gen_ref=org.objectweb.jorm.mapper.rdb.generator.RdbGenRef@1bde3d2
				//fieldName=user_username
                fieldval = adapter.getString(resultSet, 3, null);
                if (resultSet.wasNull()) {
                    refname = pClassMapping.userPnc.decodeString(null);
                } else {
                    refname = pClassMapping.userPnc.decodeString((java.lang.String) fieldval);
                }
                paccessorGen.paSetRefField(pClassMapping.user_NAME, refname, conn);
			}
		} catch (PException pe) {
			resex = pe;
		} catch (Exception pe) {
			resex = new PExceptionIO(pe, "Problem while reading the DSI.");
		} finally {
		    try {
		        if (resultSet != null) {
			        resultSet.close();
			        resultSet = null;
			    }
			    if (pstmt != null) {
			        pstmt.close();
			        pstmt = null;
			    }
			} catch (SQLException se) {
				if (resex == null) {
			    	resex = new PExceptionIO(se, "Problem while closing ResultSet or Statment");
			    }
			}
			if (resex != null) {
				throw resex;
			}
		}
		status = nextState;
	}

	public void read(Object conn, PAccessor pa, Object txctx) throws PException {
	    PrefetchCache pc = pClassMapping.getPMapper().getPrefetchCache();
	    if (pc == null || txctx == null) {
	        read(conn, pa);
	        return;
	    }
	    try {
	        Tuple tuple = pc.getPrefetchTuple(pname, pClassMapping, txctx);
	        if (tuple == null) {
	            read(conn, pa);
	            return;
	        }
		    Olstore_orderAccessor paccessor = null;
		    PAccessorGen paccessorGen = null;
		    if (pa == null)
			    throw new PExceptionProtocol("Accessor must not be null");
		    else if (pa instanceof Olstore_orderAccessor)
			    paccessor = (Olstore_orderAccessor) pa;
		    else if (pa instanceof PAccessorGen)
			    paccessorGen = (PAccessorGen) pa;
		    else
			    throw new PExceptionProtocol("Wrong type of accessor: " + pa);
		    byte nextState = PStateGraph.nextStatePBinding(status, PBinding.ACTION_READ);
		    if (nextState==PBinding.LIFECYCLE_ERROR)
			    throw new PExceptionProtocol("Unauthorized READ operation, status=" + status);
            Object fval;
            long notnullval;
            if (paccessor != null) {
                paccessor.paSetDateReceived(tuple.getString(1));
				fval =
					(Integer) tuple.getObject(2);
                if (tuple.isDefined(2)) {
                    paccessor.paSetItem(pClassMapping.itemPnc.decodeOint((java.lang.Integer) fval), conn);
                } else {
                    paccessor.paSetItem(pClassMapping.itemPnc.getNull(), conn);
                }
                paccessor.paSetOrderId((Integer) tuple.getObject(4));
                paccessor.paSetPricePaid((BigDecimal) tuple.getObject(5));
                paccessor.paSetQuantity((Integer) tuple.getObject(6));
                paccessor.paSetStatus(tuple.getString(7));
				fval =
					tuple.getString(3);
                if (tuple.isDefined(3)) {
                    paccessor.paSetUser(pClassMapping.userPnc.decodeString((java.lang.String) fval), conn);
                } else {
                    paccessor.paSetUser(pClassMapping.userPnc.getNull(), conn);
                }
            } else if (paccessorGen != null) {
                paccessorGen.paSetStringField(pClassMapping.dateReceived_NAME, tuple.getString(1));
				fval =
					(Integer) tuple.getObject(2);
                if (tuple.isDefined(2)) {
                    paccessorGen.paSetRefField(pClassMapping.item_NAME, pClassMapping.itemPnc.decodeOint((java.lang.Integer) fval), conn);
                } else {
                    paccessorGen.paSetRefField(pClassMapping.item_NAME, pClassMapping.itemPnc.getNull(), conn);
                }
                paccessorGen.paSetOintField(pClassMapping.orderId_NAME, (Integer) tuple.getObject(4));
                paccessorGen.paSetBigDecimalField(pClassMapping.pricePaid_NAME, (BigDecimal) tuple.getObject(5));
                paccessorGen.paSetOintField(pClassMapping.quantity_NAME, (Integer) tuple.getObject(6));
                paccessorGen.paSetStringField(pClassMapping.status_NAME, tuple.getString(7));
				fval =
					tuple.getString(3);
                if (tuple.isDefined(3)) {
                    paccessorGen.paSetRefField(pClassMapping.user_NAME, pClassMapping.userPnc.decodeString((java.lang.String) fval), conn);
                } else {
                    paccessorGen.paSetRefField(pClassMapping.user_NAME, pClassMapping.userPnc.getNull(), conn);
                }
            }
		    status = nextState;
		} catch (MedorException me) {
		    throw new PExceptionProtocol(me, "Problem while trying to prefetch data from Medor");
		}
    }

	public boolean exist(Object conn) throws PException {
		if (Debug.ON && pClassMapping!=null && pClassMapping.logger.isLoggable(BasicLevel.DEBUG)) pClassMapping.logger.log(BasicLevel.DEBUG, "Exist");
		byte nextState =
			PStateGraph.nextStatePBinding(status, PBinding.ACTION_EXIST);
		if (nextState==PBinding.LIFECYCLE_ERROR)
			throw new PExceptionProtocol("Unauthorized EXIST operation, status=" + status);
		status = nextState;
		Connection connection = RdbConnectionWrapper.narrow2SQL(conn);
        PreparedStatement pstmt = null;
        ResultSet rs = null;
        PException resex = null;
        boolean exist = false;
		try {
            pstmt = connection.prepareStatement("SELECT olstore_order.orderId FROM olstore_order WHERE olstore_order.orderId = ?");
            adapter.setOint(pstmt, 1, pname.encodeOint());
			rs = pstmt.executeQuery();
            exist = rs.next();
		} catch (java.sql.SQLException se) {
			resex = new PExceptionIO(se, "SQL problem while testing the existence of a DSI.");
		} finally {
		    try {
			    if (rs != null) {
			        rs.close();
			        rs = null;
			    }
			    if (pstmt != null) {
			        pstmt.close();
			        pstmt = null;
			    }
			} catch (SQLException se) {
				if (resex == null) {
					resex = new PExceptionIO(se, "Problem while closing ResultSet or Statment");
			    }
			}
			if (resex != null) {
				throw resex;
			}
		}
		return exist;
	}

	public PName export(Object conn) throws PException {
		if (Debug.ON && pClassMapping!=null && pClassMapping.logger.isLoggable(BasicLevel.DEBUG)) pClassMapping.logger.log(BasicLevel.DEBUG, "Export");
		return pClassMapping.getPBinder().export(conn, this);
	}

	public PName export(Object conn, Object hints)
		throws PException {
		if (Debug.ON && pClassMapping!=null && pClassMapping.logger.isLoggable(BasicLevel.DEBUG)) pClassMapping.logger.log(BasicLevel.DEBUG, "Export with hints");
		return pClassMapping.getPBinder().export(conn, this, hints);
	}

	public void unexport(Object conn) throws PException {
		if (Debug.ON && pClassMapping!=null && pClassMapping.logger.isLoggable(BasicLevel.DEBUG)) pClassMapping.logger.log(BasicLevel.DEBUG, "Unexport");
        pClassMapping.getPBinder().unexport(conn, this.pname, this);
	}

	public void bind(PName pn) throws PException {
		if (Debug.ON && pClassMapping!=null && pClassMapping.logger.isLoggable(BasicLevel.DEBUG)) pClassMapping.logger.log(BasicLevel.DEBUG, "Bind");
		// The Pbinding must be unbinded only if the PName has been already
		// defined
		if (pname!=null)
			pClassMapping.getPBinder().unbind(this);
		pClassMapping.getPBinder().bind(pn, this);
	}

	public void unbind() throws PException {
		if (Debug.ON && pClassMapping!=null && pClassMapping.logger.isLoggable(BasicLevel.DEBUG)) pClassMapping.logger.log(BasicLevel.DEBUG, "Unbind");
		pClassMapping.getPBinder().unbind(this);
	}

	public PClassMapping getPClassMapping() {
		return pClassMapping;
	}

	public PName getPName() {
		return pname;
	}

	public byte getStatus() {
		return status;
	}

	// IMPLEMENTATION OF METHODS FROM THE PBindingCtrl INTERFACE

	public void setPName(PName pn) {
		pname = pn;
	}

	public void setStatus(byte s) {
		status = s;
	}

    private String updateolstore_orderTable(
        Connection connection,
        Object conn,
        PAccessorGen paccessorGen,
        Olstore_orderAccessor paccessor)
        throws PException, SQLException, IOException, RdbAdapterException {
		Object nullField = null;
        String res = null;
        PreparedStatement pstmt = null;
        try {
            if (paccessor != null) {
            pstmt = connection.prepareStatement(res = "UPDATE olstore_order SET dateReceived = ?, olstore_user_username = ?, olstore_item_itemId = ?, pricePaid = ?, orderId = ?, status = ?, quantity = ? WHERE orderId = ?");
				//dateReceived
                nullField = paccessor.paGetDateReceived();
                if (nullField == null) {
                    adapter.setNull(pstmt, 1, adapter.getSqlTypeCode(PTypeSpace.STRING.getTypeCode(), null));
                } else {
                   	adapter.setString(pstmt, 1, ((java.lang.String) nullField));
                }
				//olstore_user_username
                nullField = pClassMapping.userPnc.encodeString(paccessor.paGetUser(conn));
                if (nullField == null) {
                    adapter.setNull(pstmt, 2, adapter.getSqlTypeCode(PTypeSpace.STRING.getTypeCode(), null));
                } else {
                   	adapter.setString(pstmt, 2, ((java.lang.String) nullField));
                }
				//olstore_item_itemId
                nullField = pClassMapping.itemPnc.encodeOint(paccessor.paGetItem(conn));
                if (nullField == null) {
                    adapter.setNull(pstmt, 3, adapter.getSqlTypeCode(PTypeSpace.OBJINT.getTypeCode(), null));
                } else {
                   	adapter.setOint(pstmt, 3, ((java.lang.Integer) nullField));
                }
				//pricePaid
                nullField = paccessor.paGetPricePaid();
                if (nullField == null) {
                    adapter.setNull(pstmt, 4, adapter.getSqlTypeCode(PTypeSpace.BIGDECIMAL.getTypeCode(), null));
                } else {
                   	adapter.setBigDecimal(pstmt, 4, ((java.math.BigDecimal) nullField));
                }
				//orderId
                nullField = paccessor.paGetOrderId();
                if (nullField == null) {
                    adapter.setNull(pstmt, 5, adapter.getSqlTypeCode(PTypeSpace.OBJINT.getTypeCode(), null));
                } else {
                   	adapter.setOint(pstmt, 5, ((java.lang.Integer) nullField));
                }
				//status
                nullField = paccessor.paGetStatus();
                if (nullField == null) {
                    adapter.setNull(pstmt, 6, adapter.getSqlTypeCode(PTypeSpace.STRING.getTypeCode(), null));
                } else {
                   	adapter.setString(pstmt, 6, ((java.lang.String) nullField));
                }
				//quantity
                nullField = paccessor.paGetQuantity();
                if (nullField == null) {
                    adapter.setNull(pstmt, 7, adapter.getSqlTypeCode(PTypeSpace.OBJINT.getTypeCode(), null));
                } else {
                   	adapter.setOint(pstmt, 7, ((java.lang.Integer) nullField));
                }
				//orderId
                nullField = paccessor.paGetOrderId();
                if (nullField == null) {
                    adapter.setNull(pstmt, 8, adapter.getSqlTypeCode(PTypeSpace.OBJINT.getTypeCode(), null));
                } else {
                   	adapter.setOint(pstmt, 8, ((java.lang.Integer) nullField));
                }
            } else if (paccessorGen != null) {
            pstmt = connection.prepareStatement(res = "UPDATE olstore_order SET dateReceived = ?, olstore_user_username = ?, olstore_item_itemId = ?, pricePaid = ?, orderId = ?, status = ?, quantity = ? WHERE orderId = ?");
				//dateReceived
                nullField = paccessorGen.paGetStringField(pClassMapping.dateReceived_NAME);
                if (nullField == null) {
                    adapter.setNull(pstmt, 1, adapter.getSqlTypeCode(PTypeSpace.STRING.getTypeCode(), null));
                } else {
                   	adapter.setString(pstmt, 1, ((java.lang.String) nullField));
                }
				//olstore_user_username
                nullField = pClassMapping.userPnc.encodeString(paccessorGen.paGetRefField(pClassMapping.user_NAME, conn));
                if (nullField == null) {
                    adapter.setNull(pstmt, 2, adapter.getSqlTypeCode(PTypeSpace.STRING.getTypeCode(), null));
                } else {
                   	adapter.setString(pstmt, 2, ((java.lang.String) nullField));
                }
				//olstore_item_itemId
                nullField = pClassMapping.itemPnc.encodeOint(paccessorGen.paGetRefField(pClassMapping.item_NAME, conn));
                if (nullField == null) {
                    adapter.setNull(pstmt, 3, adapter.getSqlTypeCode(PTypeSpace.OBJINT.getTypeCode(), null));
                } else {
                   	adapter.setOint(pstmt, 3, ((java.lang.Integer) nullField));
                }
				//pricePaid
                nullField = paccessorGen.paGetBigDecimalField(pClassMapping.pricePaid_NAME);
                if (nullField == null) {
                    adapter.setNull(pstmt, 4, adapter.getSqlTypeCode(PTypeSpace.BIGDECIMAL.getTypeCode(), null));
                } else {
                   	adapter.setBigDecimal(pstmt, 4, ((java.math.BigDecimal) nullField));
                }
				//orderId
                nullField = paccessorGen.paGetOintField(pClassMapping.orderId_NAME);
                if (nullField == null) {
                    adapter.setNull(pstmt, 5, adapter.getSqlTypeCode(PTypeSpace.OBJINT.getTypeCode(), null));
                } else {
                   	adapter.setOint(pstmt, 5, ((java.lang.Integer) nullField));
                }
				//status
                nullField = paccessorGen.paGetStringField(pClassMapping.status_NAME);
                if (nullField == null) {
                    adapter.setNull(pstmt, 6, adapter.getSqlTypeCode(PTypeSpace.STRING.getTypeCode(), null));
                } else {
                   	adapter.setString(pstmt, 6, ((java.lang.String) nullField));
                }
				//quantity
                nullField = paccessorGen.paGetOintField(pClassMapping.quantity_NAME);
                if (nullField == null) {
                    adapter.setNull(pstmt, 7, adapter.getSqlTypeCode(PTypeSpace.OBJINT.getTypeCode(), null));
                } else {
                   	adapter.setOint(pstmt, 7, ((java.lang.Integer) nullField));
                }
				//orderId
                nullField = paccessor.paGetOrderId();
                if (nullField == null) {
                    adapter.setNull(pstmt, 8, adapter.getSqlTypeCode(PTypeSpace.OBJINT.getTypeCode(), null));
                } else {
                   	adapter.setOint(pstmt, 8, ((java.lang.Integer) nullField));
                }
            }
            if (pstmt.executeUpdate() == 1) {
                res = null;
            }
        } finally {
            if (pstmt != null) {
                pstmt.close();
                pstmt = null;
            }
        }
        return res;
    }
    private String insertolstore_orderTable(Connection connection,
                                                Object conn,
                                                PAccessorGen paccessorGen,
                                                Olstore_orderAccessor paccessor)
        throws PException, SQLException, IOException, RdbAdapterException {

		Object nullField = null;
        String res = null;
        PreparedStatement pstmt = null;
        try {
            if (paccessor != null) {
                pstmt = connection.prepareStatement(res = "INSERT INTO olstore_order (dateReceived, olstore_user_username, olstore_item_itemId, pricePaid, orderId, status, quantity) VALUES (?, ?, ?, ?, ?, ?, ?)");
				//dateReceived
                nullField = paccessor.paGetDateReceived();
                if (nullField == null) {
                    adapter.setNull(pstmt, 1, adapter.getSqlTypeCode(PTypeSpace.STRING.getTypeCode(), null));
                } else {
                   	adapter.setString(pstmt, 1, ((java.lang.String) nullField));
                }
				//olstore_user_username
                nullField = pClassMapping.userPnc.encodeString(paccessor.paGetUser(conn));
                if (nullField == null) {
                    adapter.setNull(pstmt, 2, adapter.getSqlTypeCode(PTypeSpace.STRING.getTypeCode(), null));
                } else {
                   	adapter.setString(pstmt, 2, ((java.lang.String) nullField));
                }
				//olstore_item_itemId
                nullField = pClassMapping.itemPnc.encodeOint(paccessor.paGetItem(conn));
                if (nullField == null) {
                    adapter.setNull(pstmt, 3, adapter.getSqlTypeCode(PTypeSpace.OBJINT.getTypeCode(), null));
                } else {
                   	adapter.setOint(pstmt, 3, ((java.lang.Integer) nullField));
                }
				//pricePaid
                nullField = paccessor.paGetPricePaid();
                if (nullField == null) {
                    adapter.setNull(pstmt, 4, adapter.getSqlTypeCode(PTypeSpace.BIGDECIMAL.getTypeCode(), null));
                } else {
                   	adapter.setBigDecimal(pstmt, 4, ((java.math.BigDecimal) nullField));
                }
				//orderId
                nullField = paccessor.paGetOrderId();
                if (nullField == null) {
                    adapter.setNull(pstmt, 5, adapter.getSqlTypeCode(PTypeSpace.OBJINT.getTypeCode(), null));
                } else {
                   	adapter.setOint(pstmt, 5, ((java.lang.Integer) nullField));
                }
				//status
                nullField = paccessor.paGetStatus();
                if (nullField == null) {
                    adapter.setNull(pstmt, 6, adapter.getSqlTypeCode(PTypeSpace.STRING.getTypeCode(), null));
                } else {
                   	adapter.setString(pstmt, 6, ((java.lang.String) nullField));
                }
				//quantity
                nullField = paccessor.paGetQuantity();
                if (nullField == null) {
                    adapter.setNull(pstmt, 7, adapter.getSqlTypeCode(PTypeSpace.OBJINT.getTypeCode(), null));
                } else {
                   	adapter.setOint(pstmt, 7, ((java.lang.Integer) nullField));
                }
            } else if (paccessorGen != null) {
                pstmt = connection.prepareStatement(res = "INSERT INTO olstore_order (dateReceived, olstore_user_username, olstore_item_itemId, pricePaid, orderId, status, quantity) VALUES (?, ?, ?, ?, ?, ?, ?)");
				//dateReceived
                nullField = paccessorGen.paGetStringField(pClassMapping.dateReceived_NAME);
                if (nullField == null) {
                    adapter.setNull(pstmt, 1, adapter.getSqlTypeCode(PTypeSpace.STRING.getTypeCode(), null));
                } else {
                   	adapter.setString(pstmt, 1, ((java.lang.String) nullField));
                }
				//olstore_user_username
                nullField = pClassMapping.userPnc.encodeString(paccessorGen.paGetRefField(pClassMapping.user_NAME, conn));
                if (nullField == null) {
                    adapter.setNull(pstmt, 2, adapter.getSqlTypeCode(PTypeSpace.STRING.getTypeCode(), null));
                } else {
                   	adapter.setString(pstmt, 2, ((java.lang.String) nullField));
                }
				//olstore_item_itemId
                nullField = pClassMapping.itemPnc.encodeOint(paccessorGen.paGetRefField(pClassMapping.item_NAME, conn));
                if (nullField == null) {
                    adapter.setNull(pstmt, 3, adapter.getSqlTypeCode(PTypeSpace.OBJINT.getTypeCode(), null));
                } else {
                   	adapter.setOint(pstmt, 3, ((java.lang.Integer) nullField));
                }
				//pricePaid
                nullField = paccessorGen.paGetBigDecimalField(pClassMapping.pricePaid_NAME);
                if (nullField == null) {
                    adapter.setNull(pstmt, 4, adapter.getSqlTypeCode(PTypeSpace.BIGDECIMAL.getTypeCode(), null));
                } else {
                   	adapter.setBigDecimal(pstmt, 4, ((java.math.BigDecimal) nullField));
                }
				//orderId
                nullField = paccessorGen.paGetOintField(pClassMapping.orderId_NAME);
                if (nullField == null) {
                    adapter.setNull(pstmt, 5, adapter.getSqlTypeCode(PTypeSpace.OBJINT.getTypeCode(), null));
                } else {
                   	adapter.setOint(pstmt, 5, ((java.lang.Integer) nullField));
                }
				//status
                nullField = paccessorGen.paGetStringField(pClassMapping.status_NAME);
                if (nullField == null) {
                    adapter.setNull(pstmt, 6, adapter.getSqlTypeCode(PTypeSpace.STRING.getTypeCode(), null));
                } else {
                   	adapter.setString(pstmt, 6, ((java.lang.String) nullField));
                }
				//quantity
                nullField = paccessorGen.paGetOintField(pClassMapping.quantity_NAME);
                if (nullField == null) {
                    adapter.setNull(pstmt, 7, adapter.getSqlTypeCode(PTypeSpace.OBJINT.getTypeCode(), null));
                } else {
                   	adapter.setOint(pstmt, 7, ((java.lang.Integer) nullField));
                }
            }
            if (pstmt.executeUpdate() == 1) {
                res = null;
            }
        } finally {
            if (pstmt != null) {
                pstmt.close();
                pstmt = null;
            }
        }
        return res;
    }
    private String deleteolstore_orderTable(
    	Connection connection,
    	Object conn,
    	PAccessorGen paccessorGen,
    	Olstore_orderAccessor paccessor) throws PException, SQLException, RdbAdapterException {
		Object nullField = null;
        String res = null;
        PreparedStatement pstmt = null;
        try {
            pstmt = connection.prepareStatement(res = "DELETE FROM olstore_order WHERE orderId = ?");
				//orderId
                nullField = paccessor.paGetOrderId();
                if (nullField == null) {
                    adapter.setNull(pstmt, 1, adapter.getSqlTypeCode(PTypeSpace.OBJINT.getTypeCode(), null));
                } else {
                   	adapter.setOint(pstmt, 1, ((java.lang.Integer) nullField));
                }
            if (pstmt.executeUpdate() == 1) {
                res = null;
            }
        } finally {
            if (pstmt != null) {
                pstmt.close();
                pstmt = null;
            }
        }
        return res;
    }
}

















